==> monocdk-1.106.1.tar.gz: package/lib/aws-cognito/lib/user-pool-resource-server.d.ts <==
import { IResource, Resource } from "../../core";
import { Construct } from 'constructs';
import { IUserPool } from './user-pool';
/**
 * (experimental) Represents a Cognito user pool resource server.
 *
 * @experimental
 */
export interface IUserPoolResourceServer extends IResource {
    /**
     * (experimental) Resource server id.
     *
     * @experimental
     * @attribute true
     */
    readonly userPoolResourceServerId: string;
}
/**
 * (experimental) Props to initialize ResourceServerScope.
 *
 * @experimental
 */
export interface ResourceServerScopeProps {
    /**
     * (experimental) The name of the scope.
     *
     * @experimental
     */
    readonly scopeName: string;
    /**
     * (experimental) A description of the scope.
     *
     * @experimental
     */
    readonly scopeDescription: string;
}
/**
 * (experimental) A scope for ResourceServer.
 *
 * @experimental
 */
export declare class ResourceServerScope {
    /**
     * (experimental) The name of the scope.
     *
     * @experimental
     */
    readonly scopeName: string;
    /**
     * (experimental) A description of the scope.
     *
     * @experimental
     */
    readonly scopeDescription: string;
    /**
     * @experimental
     */
    constructor(props: ResourceServerScopeProps);
}
/**
 * (experimental) Options to create a UserPoolResourceServer.
 *
 * @experimental
 */
export interface UserPoolResourceServerOptions {
    /**
     * (experimental) A unique resource server identifier for the resource server.
     *
     * @experimental
     */
    readonly identifier: string;
    /**
     * (experimental) A friendly name for the resource server.
     *
     * @default - same as `identifier`
     * @experimental
     */
    readonly userPoolResourceServerName?: string;
    /**
     * (experimental) Oauth scopes.
     *
     * @default - No scopes will be added
     * @experimental
     */
    readonly scopes?: ResourceServerScope[];
}
/**
 * (experimental) Properties for the UserPoolResourceServer construct.
 *
 * @experimental
 */
export interface UserPoolResourceServerProps extends UserPoolResourceServerOptions {
    /**
     * (experimental) The user pool to add this resource server to.
     *
     * @experimental
     */
    readonly userPool: IUserPool;
}
/**
 * (experimental) Defines a User Pool OAuth2.0 Resource Server.
 *
 * @experimental
 */
export declare class UserPoolResourceServer extends Resource implements IUserPoolResourceServer {
    /**
     * (experimental) Import a user pool resource client given its id.
     *
     * @experimental
     */
    static fromUserPoolResourceServerId(scope: Construct, id: string, userPoolResourceServerId: string): IUserPoolResourceServer;
    /**
     * (experimental) Resource server id.
     *
     * @experimental
     */
    readonly userPoolResourceServerId: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: UserPoolResourceServerProps);
}

==> monocdk-1.191.0.tar.gz: package/lib/aws-cognito/lib/user-pool-resource-server.d.ts <==
import { IResource, Resource } from '../../core';
import { Construct } from 'constructs';
import { IUserPool } from './user-pool';
/**
 * Represents a Cognito user pool resource server
 */
export interface IUserPoolResourceServer extends IResource {
    /**
     * Resource server id
     * @attribute
     */
    readonly userPoolResourceServerId: string;
}
/**
 * Props to initialize ResourceServerScope
 */
export interface ResourceServerScopeProps {
    /**
     * The name of the scope
     */
    readonly scopeName: string;
    /**
     * A description of the scope.
     */
    readonly scopeDescription: string;
}
/**
 * A scope for ResourceServer
 */
export declare class ResourceServerScope {
    /**
     * The name of the scope
     */
    readonly scopeName: string;
    /**
     * A description of the scope.
     */
    readonly scopeDescription: string;
    constructor(props: ResourceServerScopeProps);
}
/**
 * Options to create a UserPoolResourceServer
 */
export interface UserPoolResourceServerOptions {
    /**
     * A unique resource server identifier for the resource server.
     */
    readonly identifier: string;
    /**
     * A friendly name for the resource server.
     * @default - same as `identifier`
     */
    readonly userPoolResourceServerName?: string;
    /**
     * Oauth scopes
     * @default - No scopes will be added
     */
    readonly scopes?: ResourceServerScope[];
}
/**
 * Properties for the UserPoolResourceServer construct
 */
export interface UserPoolResourceServerProps extends UserPoolResourceServerOptions {
    /**
     * The user pool to add this resource server to
     */
    readonly userPool: IUserPool;
}
/**
 * Defines a User Pool OAuth2.0 Resource Server
 */
export declare class UserPoolResourceServer extends Resource implements IUserPoolResourceServer {
    /**
     * Import a user pool resource client given its id.
     */
    static fromUserPoolResourceServerId(scope: Construct, id: string, userPoolResourceServerId: string): IUserPoolResourceServer;
    readonly userPoolResourceServerId: string;
    constructor(scope: Construct, id: string, props: UserPoolResourceServerProps);
}
